function [position, velocity, acceleration] = quintic( time, duration, distance )
% [position, velocity, acceleration] = quintic( time, duration, distance )
% Evaluate a 5th order spline trajectory at the given time.
if time < 0.0
 position = 0.0;
 velocity = 0.0;
 acceleration = 0.0;
 return
end
if time > duration
 position = distance;
 velocity = 0.0;
 acceleration = 0.0;
 return
end
scaled_time = time/duration;
st2 = scaled_time*scaled_time;
st3 = scaled_time*st2;
st4 = scaled_time*st3;
st5 = scaled_time*st4;
position = distance*( 6*st5 -15*st4 + 10*st3 );
velocity = distance*( 30*st4 -60*st3 + 30*st2 )/duration;
acceleration = distance*( 120*st3 -180*st2 + 60*scaled_time )/(duration*duration);
