function [position, velocity, acceleration] = quintic2( time, duration, p0, v0, a0, p1, v1, a1 )
% [position, velocity, acceleration] = quintic( time, duration, p0, v0, a0, p1, v1, a1 )
% Evaluate a 5th order spline trajectory at the given time.
if time <= 0.0
 position = p0;
 velocity = v0;
 acceleration = a0;
 return
end
if time >= duration
 position = p1;
 velocity = v1;
 acceleration = a1;
 return
end
if duration < 1e-5
 % spline too short, just give up
 position = p1;
 velocity = v1;
 acceleration = a1;
 return
end
nv0 = v0*duration;
nv1 = v1*duration;
na0 = a0*duration*duration;
na1 = a1*duration*duration;
f = p0;
e = nv0;
d = na0/2;
tmp1 = na0/2 + nv0 + p0 - p1;
tmp2 = na0 + nv0 - nv1;
tmp3 = na0 - na1;
a = - ( tmp3 - 6*tmp2 + 12*tmp1 )/2;
b = - ( 8*a + 4*tmp2 - 12*tmp1 )/4;
c = - ( a + b + tmp1 );
t1 = time/duration;
t2 = t1*t1;
t3 = t2*t1;
t4 = t3*t1;
t5 = t4*t1;
position = a*t5 + b*t4 + c*t3 + d*t2 + e*t1 + f;
velocity = (5*a*t4 + 4*b*t3 + 3*c*t2 + 2*d*t1 + e)/duration;
acceleration = (20*a*t3 + 12*b*t2 + 6*c*t1 + 2*d)/(duration*duration);




